summaryrefslogtreecommitdiff
path: root/chromium/components/assist_ranker/assist_ranker_service_impl.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/components/assist_ranker/assist_ranker_service_impl.h')
-rw-r--r--chromium/components/assist_ranker/assist_ranker_service_impl.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/chromium/components/assist_ranker/assist_ranker_service_impl.h b/chromium/components/assist_ranker/assist_ranker_service_impl.h
index 1b75ff4017f..e1b00c284a9 100644
--- a/chromium/components/assist_ranker/assist_ranker_service_impl.h
+++ b/chromium/components/assist_ranker/assist_ranker_service_impl.h
@@ -15,8 +15,8 @@
#include "components/assist_ranker/assist_ranker_service.h"
#include "components/assist_ranker/predictor_config.h"
-namespace net {
-class URLRequestContextGetter;
+namespace network {
+class SharedURLLoaderFactory;
}
namespace assist_ranker {
@@ -28,7 +28,7 @@ class AssistRankerServiceImpl : public AssistRankerService {
public:
AssistRankerServiceImpl(
base::FilePath base_path,
- net::URLRequestContextGetter* url_request_context_getter);
+ scoped_refptr<network::SharedURLLoaderFactory> url_loader_factory);
~AssistRankerServiceImpl() override;
// AssistRankerService...
@@ -39,8 +39,8 @@ class AssistRankerServiceImpl : public AssistRankerService {
// Returns the full path to the model cache.
base::FilePath GetModelPath(const std::string& model_filename);
- // Request Context Getter used for RankerURLFetcher.
- scoped_refptr<net::URLRequestContextGetter> url_request_context_getter_;
+ // URL loader factory used for RankerURLFetcher.
+ scoped_refptr<network::SharedURLLoaderFactory> url_loader_factory_;
// Base path where models are stored.
const base::FilePath base_path_;